package App::lens;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-06-13'; # DATE
our $DIST = 'App-lens'; # DIST
our $VERSION = '0.020'; # VERSION

1;
# ABSTRACT: Transform colors in terminal output

__END__

=pod

=encoding UTF-8

=head1 NAME

App::lens - Transform colors in terminal output

=head1 VERSION

This document describes version 0.020 of App::lens (from Perl distribution App-lens), released on 2020-06-13.

=head1 DESCRIPTION

See included script L<lens>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-lens>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-lens>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lens>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<lens>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
